@@ -61,8 +61,8 @@ class BaseAsyncResult(object):
         self.app.control.revoke(self.task_id, connection=connection,
                                 connect_timeout=connect_timeout)
 
-    def wait(self, timeout=None, propagate=True, interval=0.5):
-        """Wait for task, and return the result.
+    def get(self, timeout=None, propagate=True, interval=0.5):
+        """Wait until task is ready, and return its result.
 
         .. warning::
 
@@ -89,9 +89,9 @@ class BaseAsyncResult(object):
                                                    propagate=propagate,
                                                    interval=interval)
 
-    def get(self, timeout=None):
-        """Alias to :meth:`wait`."""
-        return self.wait(timeout=timeout)
+    def wait(self, *args, **kwargs):
+        """Deprecated alias to :meth:`get`."""
+        return self.get(*args, **kwargs)
 
     def ready(self):
         """Returns :const:`True` if the task has been executed.
@@ -329,27 +329,27 @@ class TaskSetResult(object):
                     raise result.result
 
     def join(self, timeout=None, propagate=True, interval=0.5):
-        """Gather the results of all tasks in the taskset,
+        """Gathers the results of all tasks in the taskset,
         and returns a list ordered by the order of the set.
 
         .. note::
 
-            This can be an very expensive operation on result store
+            This can be an expensive operation for result store
             backends that must resort to polling (e.g. database).
 
-            You should consider using :meth:`join_native` if your backends
+            You should consider using :meth:`join_native` if your backend
             supports it.
 
         .. warning::
 
-            Waiting for subtasks may lead the deadlocks.
+            Waiting for subtasks may lead to deadlocks.
             Please see :ref:`task-synchronous-subtasks`.
 
         :keyword timeout: The number of seconds to wait for results before
                           the operation times out.
 
         :keyword propagate: If any of the subtasks raises an exception, the
-                            exception will be reraised.
+                            exception will be re-raised.
 
         :keyword interval: Time to wait (in seconds) before retrying to
                            retrieve a result from the set.  Note that this
@@ -456,7 +456,7 @@ class EagerResult(BaseAsyncResult):
         """Returns :const:`True` if the task has been executed."""
         return True
 
-    def wait(self, timeout=None, propagate=True, **kwargs):
+    def get(self, timeout=None, propagate=True, **kwargs):
         """Wait until the task has been executed and return its result."""
         if self.state == states.SUCCESS:
             return self.result
