@@ -1,13 +1,12 @@
 import threading
-import time
 
 from collections import deque
-from Queue import Queue, Empty as QueueEmpty
+from time import time, sleep
+from Queue import Queue, Empty
 
 from celery.datastructures import TokenBucket
-from celery.utils import all
 from celery.utils import timeutils
-from celery.utils.compat import izip_longest, chain_from_iterable
+from celery.utils.compat import all, izip_longest, chain_from_iterable
 
 
 class RateLimitExceeded(Exception):
@@ -16,16 +15,16 @@ class RateLimitExceeded(Exception):
 
 class TaskBucket(object):
     """This is a collection of token buckets, each task type having
-    its own token bucket. If the task type doesn't have a rate limit,
-    it will have a plain :class:`Queue` object instead of a
+    its own token bucket.  If the task type doesn't have a rate limit,
+    it will have a plain :class:`~Queue.Queue` object instead of a
     :class:`TokenBucketQueue`.
 
     The :meth:`put` operation forwards the task to its appropriate bucket,
     while the :meth:`get` operation iterates over the buckets and retrieves
     the first available item.
 
-    Say we have three types of tasks in the registry: ``celery.ping``,
-    ``feed.refresh`` and ``video.compress``, the TaskBucket will consist
+    Say we have three types of tasks in the registry: `celery.ping`,
+    `feed.refresh` and `video.compress`, the TaskBucket will consist
     of the following items::
 
         {"celery.ping": TokenBucketQueue(fill_rate=300),
@@ -33,12 +32,11 @@ class TaskBucket(object):
          "video.compress": TokenBucketQueue(fill_rate=2)}
 
     The get operation will iterate over these until one of the buckets
-    is able to return an item. The underlying datastructure is a ``dict``,
+    is able to return an item.  The underlying datastructure is a `dict`,
     so the order is ignored here.
 
     :param task_registry: The task registry used to get the task
-        type class for a given task name.
-
+                          type class for a given task name.
 
     """
 
@@ -66,8 +64,8 @@ class TaskBucket(object):
     def _get_immediate(self):
         try:
             return self.immediate.popleft()
-        except IndexError:                                      # Empty
-            raise QueueEmpty()
+        except IndexError:
+            raise Empty()
 
     def _get(self):
         # If the first bucket is always returning items, we would never
@@ -76,8 +74,8 @@ class TaskBucket(object):
         # "immediate". This queue is always checked for cached items first.
         try:
             return 0, self._get_immediate()
-        except QueueEmpty:
-                pass
+        except Empty:
+            pass
 
         remaining_times = []
         for bucket in self.buckets.values():
@@ -86,7 +84,7 @@ class TaskBucket(object):
                 try:
                     # Just put any ready items into the immediate queue.
                     self.immediate.append(bucket.get_nowait())
-                except QueueEmpty:
+                except Empty:
                     pass
                 except RateLimitExceeded:
                     remaining_times.append(bucket.expected_time())
@@ -96,7 +94,7 @@ class TaskBucket(object):
         # Try the immediate queue again.
         try:
             return 0, self._get_immediate()
-        except QueueEmpty:
+        except Empty:
             if not remaining_times:
                 # No items in any of the buckets.
                 raise
@@ -112,23 +110,23 @@ class TaskBucket(object):
         consume tokens from it.
 
         """
-        time_start = time.time()
-        did_timeout = lambda: timeout and time.time() - time_start > timeout
+        time_start = time()
+        did_timeout = lambda: timeout and time() - time_start > timeout
 
         self.not_empty.acquire()
         try:
             while True:
                 try:
                     remaining_time, item = self._get()
-                except QueueEmpty:
+                except Empty:
                     if not block or did_timeout():
                         raise
                     self.not_empty.wait(timeout)
                     continue
                 if remaining_time:
                     if not block or did_timeout():
-                        raise QueueEmpty
-                    time.sleep(min(remaining_time, timeout or 1))
+                        raise Empty()
+                    sleep(min(remaining_time, timeout or 1))
                 else:
                     return item
         finally:
@@ -139,11 +137,13 @@ class TaskBucket(object):
 
     def init_with_registry(self):
         """Initialize with buckets for all the task types in the registry."""
-        map(self.add_bucket_for_type, self.task_registry.keys())
+        for task in self.task_registry.keys():
+            self.add_bucket_for_type(task)
 
     def refresh(self):
         """Refresh rate limits for all task types in the registry."""
-        map(self.update_bucket_for_type, self.task_registry.keys())
+        for task in self.task_registry.keys():
+            self.update_bucket_for_type(task)
 
     def get_bucket_for_type(self, task_name):
         """Get the bucket for a particular task type."""
@@ -177,8 +177,8 @@ class TaskBucket(object):
         """Add a bucket for a task type.
 
         Will read the tasks rate limit and create a :class:`TokenBucketQueue`
-        if it has one. If the task doesn't have a rate limit a regular Queue
-        will be used.
+        if it has one.  If the task doesn't have a rate limit
+        :class:`FastQueue` will be used instead.
 
         """
         if task_name not in self.buckets:
@@ -189,14 +189,17 @@ class TaskBucket(object):
         return sum(bucket.qsize() for bucket in self.buckets.values())
 
     def empty(self):
+        """Returns :const:`True` if all of the buckets are empty."""
         return all(bucket.empty() for bucket in self.buckets.values())
 
     def clear(self):
+        """Delete the data in all of the buckets."""
         for bucket in self.buckets.values():
             bucket.clear()
 
     @property
     def items(self):
+        """Flattens the data in all of the buckets into a single list."""
         # for queues with contents [(1, 2), (3, 4), (5, 6), (7, 8)]
         # zips and flattens to [1, 3, 5, 7, 2, 4, 6, 8]
         return filter(None, chain_from_iterable(izip_longest(*[bucket.items
@@ -228,8 +231,9 @@ class TokenBucketQueue(object):
     operations.
 
     :param fill_rate: The rate in tokens/second that the bucket will
-      be refilled.
-    :keyword capacity: Maximum number of tokens in the bucket. Default is 1.
+                      be refilled.
+    :keyword capacity: Maximum number of tokens in the bucket.
+                       Default is 1.
 
     """
     RateLimitExceeded = RateLimitExceeded
@@ -241,11 +245,7 @@ class TokenBucketQueue(object):
             self.queue = Queue()
 
     def put(self, item, block=True):
-        """Put an item into the queue.
-
-        Also see :meth:`Queue.Queue.put`.
-
-        """
+        """Put an item onto the queue."""
         self.queue.put(item, block=block)
 
     def put_nowait(self, item):
@@ -253,8 +253,6 @@ class TokenBucketQueue(object):
 
         :raises Queue.Full: If a free slot is not immediately available.
 
-        Also see :meth:`Queue.Queue.put_nowait`
-
         """
         return self.put(item, block=False)
 
@@ -262,14 +260,16 @@ class TokenBucketQueue(object):
         """Remove and return an item from the queue.
 
         :raises RateLimitExceeded: If a token could not be consumed from the
-            token bucket (consuming from the queue too fast).
+                                   token bucket (consuming from the queue
+                                   too fast).
         :raises Queue.Empty: If an item is not immediately available.
 
-        Also see :meth:`Queue.Queue.get`.
-
         """
         get = block and self.queue.get or self.queue.get_nowait
 
+        if not block and not self.items:
+            raise Empty()
+
         if not self._bucket.can_consume(1):
             raise RateLimitExceeded()
 
@@ -279,26 +279,23 @@ class TokenBucketQueue(object):
         """Remove and return an item from the queue without blocking.
 
         :raises RateLimitExceeded: If a token could not be consumed from the
-            token bucket (consuming from the queue too fast).
+                                   token bucket (consuming from the queue
+                                   too fast).
         :raises Queue.Empty: If an item is not immediately available.
 
-        Also see :meth:`Queue.Queue.get_nowait`.
-
         """
         return self.get(block=False)
 
     def qsize(self):
-        """Returns the size of the queue.
-
-        See :meth:`Queue.Queue.qsize`.
-
-        """
+        """Returns the size of the queue."""
         return self.queue.qsize()
 
     def empty(self):
+        """Returns :const:`True` if the queue is empty."""
         return self.queue.empty()
 
     def clear(self):
+        """Delete all data in the queue."""
         return self.items.clear()
 
     def wait(self, block=False):
@@ -308,13 +305,16 @@ class TokenBucketQueue(object):
             remaining = self.expected_time()
             if not remaining:
                 return self.get(block=block)
-            time.sleep(remaining)
+            sleep(remaining)
 
     def expected_time(self, tokens=1):
-        """Returns the expected time in seconds when a new token should be
+        """Returns the expected time in seconds of when a new token should be
         available."""
+        if not self.items:
+            return 0
         return self._bucket.expected_time(tokens)
 
     @property
     def items(self):
+        """Underlying data.  Do not modify."""
         return self.queue.queue
